summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/zlib/zconf.in.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/3rdparty/zlib/zconf.in.h')
-rw-r--r--src/3rdparty/zlib/zconf.in.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/3rdparty/zlib/zconf.in.h b/src/3rdparty/zlib/zconf.in.h
index c29f9709..3c21403f 100644
--- a/src/3rdparty/zlib/zconf.in.h
+++ b/src/3rdparty/zlib/zconf.in.h
@@ -142,15 +142,15 @@
# define MAX_WBITS 15 /* 32K LZ77 window */
#endif
/* The memory retquirements for deflate are (in bytes):
(1 << (windowBits+2)) + (1 << (memLevel+9))
that is: 128K for windowBits=15 + 128K for memLevel = 8 (default values)
plus a few kilobytes for small objects. For example, if you want to reduce
- the default memory retquirements from 256K to 128K, compile with
+ the default memory requirements from 256K to 128K, compile with
make CFLAGS="-O -DMAX_WBITS=14 -DMAX_MEM_LEVEL=7"
Of course this will generally degrade compression (there's no free lunch).
- The memory retquirements for inflate are (in bytes) 1 << windowBits
+ The memory requirements for inflate are (in bytes) 1 << windowBits
that is, 32K for windowBits=15 (default value) plus a few kilobytes
for small objects.
*/
@@ -142,15 +142,15 @@
# define MAX_WBITS 15 /* 32K LZ77 window */
#endif
-/* The memory retquirements for deflate are (in bytes):
+/* The memory requirements for deflate are (in bytes):
(1 << (windowBits+2)) + (1 << (memLevel+9))
that is: 128K for windowBits=15 + 128K for memLevel = 8 (default values)